You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airavata.apache.org by la...@apache.org on 2014/05/19 17:46:45 UTC

[8/9] git commit: fixing validateExperiment

fixing validateExperiment


Project: http://git-wip-us.apache.org/repos/asf/airavata/repo
Commit: http://git-wip-us.apache.org/repos/asf/airavata/commit/5632de38
Tree: http://git-wip-us.apache.org/repos/asf/airavata/tree/5632de38
Diff: http://git-wip-us.apache.org/repos/asf/airavata/diff/5632de38

Branch: refs/heads/master
Commit: 5632de388b2be1023f8082f2858cfaa2f16a4bfd
Parents: 0317c4a
Author: lahiru <la...@apache.org>
Authored: Mon May 19 11:46:04 2014 -0400
Committer: lahiru <la...@apache.org>
Committed: Mon May 19 11:46:04 2014 -0400

----------------------------------------------------------------------
 .../airavata/api/server/AiravataAPIServer.java  |    4 +-
 .../server/handler/AiravataServerHandler.java   |   56 +-
 .../java/org/apache/airavata/api/Airavata.java  | 1264 ++++++++--------
 .../api/appcatalog/ApplicationCatalogAPI.java   | 1412 +++++++++---------
 .../api/client/AiravataClientFactory.java       |    2 +-
 .../error/AiravataClientConnectException.java   |   32 -
 .../api/error/AiravataClientException.java      |  534 -------
 .../airavata/api/error/AiravataErrorType.java   |   98 --
 .../api/error/AiravataSystemException.java      |  529 -------
 .../api/error/AuthenticationException.java      |  402 -----
 .../api/error/AuthorizationException.java       |  402 -----
 .../api/error/ExperimentNotFoundException.java  |  404 -----
 .../api/error/InvalidRequestException.java      |  403 -----
 .../api/error/LaunchValidationException.java    |  508 -------
 .../airavata/api/error/TimedOutException.java   |  299 ----
 .../airavata/api/error/ValidationResults.java   |  546 -------
 .../airavata/api/error/ValidatorResult.java     |  502 -------
 .../client/samples/CreateLaunchExperiment.java  |    9 +-
 .../samples/CreateLaunchExperimentUS3.java      |    8 +-
 .../error/AiravataClientConnectException.java   |   32 +
 .../model/error/AiravataClientException.java    |  523 +++++++
 .../airavata/model/error/AiravataErrorType.java |   94 ++
 .../model/error/AiravataSystemException.java    |  518 +++++++
 .../model/error/AuthenticationException.java    |  390 +++++
 .../model/error/AuthorizationException.java     |  390 +++++
 .../error/ExperimentNotFoundException.java      |  392 +++++
 .../model/error/InvalidRequestException.java    |  391 +++++
 .../model/error/LaunchValidationException.java  |  497 ++++++
 .../airavata/model/error/TimedOutException.java |  287 ++++
 .../airavata/model/error/ValidationResults.java |  536 +++++++
 .../airavata/model/error/ValidatorResult.java   |  491 ++++++
 .../airavataAPI.thrift                          |   52 +-
 .../airavataErrors.thrift                       |    2 +-
 .../airavata/integration/DataRetrievalIT.java   |   10 +-
 .../SingleAppIntegrationTestBase.java           |    8 +-
 .../WorkflowIntegrationTestBase.java            |   10 +-
 .../server/OrchestratorServerHandler.java       |    7 +-
 .../core/validator/JobMetadataValidator.java    |   18 +-
 .../core/validator/ValidatorResult.java         |   54 -
 .../validator/impl/SimpleAppDataValidator.java  |    4 +-
 .../airavata/orchestrator/cpi/Orchestrator.java |    7 +-
 .../cpi/impl/SimpleOrchestratorImpl.java        |   59 +-
 .../orchestrator/core/ValidatorTest.java        |    6 +-
 .../orchestrator/core/util/SecondValidator.java |   10 +-
 .../orchestrator/core/util/TestValidator.java   |   12 +-
 .../airavata/api/samples/ExperimentSample.java  |   10 +-
 46 files changed, 6041 insertions(+), 6183 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/airavata/blob/5632de38/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/AiravataAPIServer.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/AiravataAPIServer.java b/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/AiravataAPIServer.java
index 7e0587a..981e002 100644
--- a/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/AiravataAPIServer.java
+++ b/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/AiravataAPIServer.java
@@ -22,8 +22,8 @@
 package org.apache.airavata.api.server;
 
 import org.apache.airavata.api.Airavata;
-import org.apache.airavata.api.error.AiravataErrorType;
-import org.apache.airavata.api.error.AiravataSystemException;
+import org.apache.airavata.model.error.AiravataErrorType;
+import org.apache.airavata.model.error.AiravataSystemException;
 import org.apache.airavata.api.server.handler.AiravataServerHandler;
 import org.apache.airavata.api.server.util.Constants;
 import org.apache.airavata.api.server.util.RegistryInitUtil;

http://git-wip-us.apache.org/repos/asf/airavata/blob/5632de38/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/handler/AiravataServerHandler.java
----------------------------------------------------------------------
diff --git a/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/handler/AiravataServerHandler.java b/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/handler/AiravataServerHandler.java
index 1beedea..15b1009 100644
--- a/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/handler/AiravataServerHandler.java
+++ b/airavata-api/airavata-api-server/src/main/java/org/apache/airavata/api/server/handler/AiravataServerHandler.java
@@ -23,7 +23,7 @@ package org.apache.airavata.api.server.handler;
 
 import org.apache.airavata.api.Airavata;
 import org.apache.airavata.api.airavataAPIConstants;
-import org.apache.airavata.api.error.*;
+import org.apache.airavata.model.error.*;
 import org.apache.airavata.model.workspace.Project;
 import org.apache.airavata.orchestrator.client.OrchestratorClientFactory;
 import org.apache.airavata.orchestrator.cpi.OrchestratorService;
@@ -217,8 +217,8 @@ public class AiravataServerHandler implements Airavata.Iface {
      * registering the experiment in a persistent store.
      *
      * @param experiment@return The server-side generated airavata experiment globally unique identifier.
      * @throws org.apache.airavata.api.error.InvalidRequestException For any incorrect forming of the request itself.
      * @throws org.apache.airavata.api.error.AiravataClientException The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                               <p/>
      *                                                               UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
      *                                                               step, then Airavata Registry will not have a provenance area setup. The client has to follow
@@ -229,7 +229,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                               <p/>
      *                                                               INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                               is implemented, the authorization will be more substantial.
      * @throws org.apache.airavata.api.error.AiravataSystemException This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                               rather an Airavata Administrator will be notified to take corrective action.
      */
     @Override
@@ -252,9 +252,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @return experimentMetada
      * This method will return the previously stored experiment metadata.
      * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
      * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
      * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
      *                                                                   step, then Airavata Registry will not have a provenance area setup. The client has to follow
@@ -265,7 +265,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   <p/>
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
      * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
     @Override
@@ -294,9 +294,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @param experiment
      * @return This method call does not have a return value.
      * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
      * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
      * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
      *                                                                   step, then Airavata Registry will not have a provenance area setup. The client has to follow
@@ -307,7 +307,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   <p/>
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
      * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
     @Override
@@ -387,9 +387,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      *
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @return This method returns the previously configured experiment configuration data.
      * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
      * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
      * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
      *                                                                   step, then Airavata Registry will not have a provenance area setup. The client has to follow
@@ -400,7 +400,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   <p/>
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
      * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
     @Override
@@ -488,11 +488,11 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                               if more security credentials are enables, then the structure ExecutionSecurityParameters should be used.
      *                               Note: This parameter is not persisted within Airavata Registry for security reasons.
      * @return This method call does not have a return value.
-     * @throws org.apache.airavata.api.error.InvalidRequestException
+     * @throws org.apache.airavata.model.error.InvalidRequestException
      *          For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException
      *          If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
-     * @throws org.apache.airavata.api.error.AiravataClientException
+     * @throws org.apache.airavata.model.error.AiravataClientException
      *          The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *          <p/>
      *          UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -504,7 +504,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *          <p/>
      *          INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *          is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException
+     * @throws org.apache.airavata.model.error.AiravataSystemException
      *          This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *          rather an Airavata Administrator will be notified to take corrective action.
      */
@@ -548,13 +548,13 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @return
      *   The server-side generated airavata experiment globally unique identifier for the newly cloned experiment.
      *
-     * @throws org.apache.airavata.api.error.InvalidRequestException
+     * @throws org.apache.airavata.model.error.InvalidRequestException
      *    For any incorrect forming of the request itself.
      *
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException
      *    If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
      *
-     * @throws org.apache.airavata.api.error.AiravataClientException
+     * @throws org.apache.airavata.model.error.AiravataClientException
      *    The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *
      *      UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -567,7 +567,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *      INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *         is implemented, the authorization will be more substantial.
      *
-     * @throws org.apache.airavata.api.error.AiravataSystemException
+     * @throws org.apache.airavata.model.error.AiravataSystemException
      *    This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *       rather an Airavata Administrator will be notified to take corrective action.
      *
@@ -601,9 +601,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      *
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @return This method call does not have a return value.
      * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
      * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
      * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
      *                                                                   step, then Airavata Registry will not have a provenance area setup. The client has to follow
@@ -614,7 +614,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   <p/>
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
      * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
     @Override
@@ -217,8 +217,8 @@ public class AiravataServerHandler implements Airavata.Iface {
      *
      * @param experiment@return The server-side generated airavata experiment globally unique identifier.
-     * @throws org.apache.airavata.api.error.InvalidRequestException For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.AiravataClientException The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
+     * @throws org.apache.airavata.model.error.InvalidRequestException For any incorrect forming of the request itself.
+     * @throws org.apache.airavata.model.error.AiravataClientException The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                               <p/>
      *                                                               UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -229,7 +229,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                               INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                               is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
+     * @throws org.apache.airavata.model.error.AiravataSystemException This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                               rather an Airavata Administrator will be notified to take corrective action.
      */
@@ -252,9 +252,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @return experimentMetada
      * This method will return the previously stored experiment metadata.
-     * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
-     * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
+     * @throws org.apache.airavata.model.error.InvalidRequestException     For any incorrect forming of the request itself.
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
+     * @throws org.apache.airavata.model.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -265,7 +265,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
+     * @throws org.apache.airavata.model.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
@@ -294,9 +294,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @param experiment
      * @return This method call does not have a return value.
-     * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
-     * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
+     * @throws org.apache.airavata.model.error.InvalidRequestException     For any incorrect forming of the request itself.
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
+     * @throws org.apache.airavata.model.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -307,7 +307,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
+     * @throws org.apache.airavata.model.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
@@ -387,9 +387,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @return This method returns the previously configured experiment configuration data.
-     * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
-     * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
+     * @throws org.apache.airavata.model.error.InvalidRequestException     For any incorrect forming of the request itself.
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
+     * @throws org.apache.airavata.model.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -400,7 +400,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
+     * @throws org.apache.airavata.model.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */
@@ -601,9 +601,9 @@ public class AiravataServerHandler implements Airavata.Iface {
      * @param airavataExperimentId The identifier for the requested experiment. This is returned during the create experiment step.
      * @return This method call does not have a return value.
-     * @throws org.apache.airavata.api.error.InvalidRequestException     For any incorrect forming of the request itself.
-     * @throws org.apache.airavata.api.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
-     * @throws org.apache.airavata.api.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
+     * @throws org.apache.airavata.model.error.InvalidRequestException     For any incorrect forming of the request itself.
+     * @throws org.apache.airavata.model.error.ExperimentNotFoundException If the specified experiment is not previously created, then an Experiment Not Found Exception is thrown.
+     * @throws org.apache.airavata.model.error.AiravataClientException     The following list of exceptions are thrown which Airavata Client can take corrective actions to resolve:
      *                                                                   <p/>
      *                                                                   UNKNOWN_GATEWAY_ID - If a Gateway is not registered with Airavata as a one time administrative
@@ -614,7 +614,7 @@ public class AiravataServerHandler implements Airavata.Iface {
      *                                                                   INVALID_AUTHORIZATION - This will throw an authorization exception. When a more robust security hand-shake
      *                                                                   is implemented, the authorization will be more substantial.
-     * @throws org.apache.airavata.api.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
+     * @throws org.apache.airavata.model.error.AiravataSystemException     This exception will be thrown for any Airavata Server side issues and if the problem cannot be corrected by the client
      *                                                                   rather an Airavata Administrator will be notified to take corrective action.
      */